<?php

namespace Newpackage\Newpackage\Providers;

use Illuminate\Support\ServiceProvider;

class NewpackageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'newpackage');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'newpackage');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('newpackage.newpackage', function ($app) {
            return $this->app->make('Newpackage\Newpackage\Newpackage');
        });

                // Bind Form to repository
        $this->app->bind(
            'Newpackage\Newpackage\Interfaces\FormRepositoryInterface',
            \Newpackage\Newpackage\Repositories\Eloquent\FormRepository::class
        );

        $this->app->register(\Newpackage\Newpackage\Providers\AuthServiceProvider::class);
                $this->app->register(\Newpackage\Newpackage\Providers\EventServiceProvider::class);
        
        $this->app->register(\Newpackage\Newpackage\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['newpackage.newpackage'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('newpackage/newpackage.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/newpackage')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/newpackage')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
